package de.intevation.flys.exports;

import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

import de.intevation.artifactdatabase.state.DefaultAttribute;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class VisibleAttribute extends DefaultAttribute {

    protected boolean visible;


    public VisibleAttribute(String name, Object value, boolean visible) {
        super(name, value);
        this.visible = visible;
    }


    /**
     * This implementation of Attribute calls DefaultAttribute.toXML() first.
     * After this, a new Attr <i>display</i> is added to the resulting Node.
     *
     * @param parent The parent Node.
     *
     * @return a new Node that represents this Attribute.
     */
    @Override
    public Node toXML(Node parent) {
        Document owner = parent.getOwnerDocument();
        Node     node  = super.toXML(parent);

        Attr attr = owner.createAttribute("display");
        attr.setValue(String.valueOf(visible));

        node.appendChild(attr);

        return node;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
